@@ -1,6 +1,7 @@
 from typing import Callable, Union
 
-from .oscillator import Oscillator
+from .oscillator import Oscillator, DEFAULT_LOOKUP
+from .utils import dependency
 from ..timeframes import Timeframes
 from ..market_data_storage import MarketDataStorage
 from ..candle_properties import CandleProperties
@@ -21,28 +22,16 @@ class SMA(Oscillator):
             name: str=None,
             seq: bool=True
     ):
-        if not name:
-            name = f'SMA_{timeframe.name}_{period}'
-        self._property_hint = property
-        self._period = period
-        self._reserved_size = period
-        self.seq = seq
-        super().__init__(market_data, timeframe, name)
+        name = name or f'SMA_{timeframe.name}_{period}'
+        deps = dependency(
+            (timeframe, property, DEFAULT_LOOKUP))
 
-    def reserve(self) -> None:
-        self._market_data.reserve(
-            self._timeframe,
-            self._property_hint,
-            self._reserved_size
-        )
+        self._period = period
+        self.seq = seq
+        super().__init__(deps, market_data, name)
 
     def __call__(self) -> Union[numpy.ndarray, float]:
-        values = self._market_data.get(
-            self._timeframe,
-            self._property_hint,
-            self._reserved_size)
-
-        values = pd.Series(values)
+        values = pd.Series(self._get_values())
         sma = ta.trend.SMAIndicator(values, self._period).sma_indicator()
         sma = sma.values
 
